@@ -67,14 +67,14 @@ struct sMatrixSize
 // -------------------------------------------------------------------------
 // Compute reference data set matrix multiply on CPU
 // C = A * B
-// @param C          reference data, computed but preallocated
-// @param A          matrix A as provided to device
-// @param B          matrix B as provided to device
-// @param hA         height of matrix A
-// @param wB         width of matrix B
+// \param C          reference data, computed but preallocated
+// \param A          matrix A as provided to device
+// \param B          matrix B as provided to device
+// \param hA         height of matrix A
+// \param wB         width of matrix B
 // -------------------------------------------------------------------------
 template <typename T>
-void matrixMulCPU(T* C, const T* A, const T* B, unsigned int hA, unsigned int wA, unsigned int wB)
+void matrixMulCPU(T* C, T const* A, T const* B, unsigned int hA, unsigned int wA, unsigned int wB)
 {
     for (unsigned int i = 0; i < hA; ++i)
     {
@@ -95,7 +95,7 @@ void matrixMulCPU(T* C, const T* A, const T* B, unsigned int hA, unsigned int wA
 // -------------------------------------------------------------------------
 // Compute the L2 norm difference between two arrays
 inline bool compare_L2_err(
-    const float* reference, const float* data, const unsigned int len, const float epsilon)
+    float const* reference, float const* data, unsigned int const len, float const epsilon)
 {
     PIKA_ASSERT(epsilon >= 0);
 
