@@ -25,6 +25,7 @@
 #include <pika/functional/detail/tag_fallback_invoke.hpp>
 #include <pika/functional/invoke.hpp>
 #include <pika/mpi_base/mpi.hpp>
+#include <pika/mpi_base/mpi_exception.hpp>
 
 #include <exception>
 #include <tuple>
@@ -151,9 +152,10 @@ namespace pika::mpi::experimental::detail {
                             {
                                 PIKA_DETAIL_DP(mpi_tran<5>,
                                     debug(str<>("set_error"), "status != MPI_SUCCESS",
-                                        detail::error_message(status)));
+                                        mpi::detail::error_message(status)));
                                 ex::set_error(PIKA_MOVE(r.op_state.receiver),
-                                    std::make_exception_ptr(mpi_exception(status)));
+                                    std::make_exception_ptr(
+                                        mpi::exception(status, "dispatch mpi")));
                                 return;
                             }
                             // early poll just in case the request completed immediately
