@@ -114,7 +114,7 @@ PIKA_NO_SANITIZE_ADDRESS void test_exception_handler_code(MPI_Comm comm, MPI_Dat
             std::vector<std::string> err_msgs = {"null datatype", "MPI_DATATYPE_NULL",
                 "Invalid datatype", "MPI_ERR_TYPE", "Invalid root"};
             bool msg_ok = false;
-            for (const auto& msg : err_msgs)
+            for (auto const& msg : err_msgs)
             {
                 msg_ok |= (std::string(e.what()).find(msg) != std::string::npos);
             }
@@ -129,7 +129,7 @@ PIKA_NO_SANITIZE_ADDRESS void test_exception_handler_code(MPI_Comm comm, MPI_Dat
 PIKA_NO_SANITIZE_ADDRESS void test_exception_no_handler(MPI_Comm comm)
 {
     // Use the default error handler MPI_ERRORS_ARE_FATAL
-    mpi::enable_user_polling enable_polling_no_errhandler;
+    mpi::enable_polling enable_polling_no_errhandler;
     {
         // Exception thrown based on the returned error code
         int *data = nullptr, count = 0;
@@ -162,9 +162,8 @@ int pika_main()
 
     {
         {
-            // Use the custom error handler from the async_mpi module which throws
-            // exceptions on error returned
-            mpi::enable_user_polling enable_polling(mpi::get_pool_name(), true);
+            // Use the custom error handler which throws exceptions on mpi errors
+            mpi::enable_polling enable_polling(mpi::exception_mode::install_handler);
             // Success path
             {
                 // MPI function pointer
@@ -235,11 +234,16 @@ int pika_main()
                 PIKA_TEST_EQ(data, 42);
             }
 
+            // MPICH does not support throwing exceptions from error handlers (lock issues, see
+            // https://github.com/pmodels/mpich/issues/7187)
+#if !defined(MPICH)
             test_exception_handler_code(comm, datatype);
 
         }    // let the user polling go out of scope
-
         test_exception_no_handler(comm);
+#else
+        }
+#endif
     }
 
     test_adl_isolation(mpi::transform_mpi(my_namespace::my_sender{}, [](MPI_Request*) {}));
@@ -248,25 +252,16 @@ int pika_main()
     return EXIT_SUCCESS;
 }
 
-//----------------------------------------------------------------------------
-void init_resource_partitioner_handler(
-    pika::resource::partitioner&, pika::program_options::variables_map const& /*vm*/)
-{
-    namespace mpix = pika::mpi::experimental;
-    mpix::create_pool("", mpix::pool_create_mode::pika_decides);
-}
-
 //----------------------------------------------------------------------------
 int main(int argc, char* argv[])
 {
-    MPI_Init(&argc, &argv);
-
-    // Set runtime initialization callback to init thread_pools
-    pika::init_params init_args;
-    init_args.rp_callback = &init_resource_partitioner_handler;
+    int provided;
+    int preferred = MPI_THREAD_MULTIPLE;
+    MPI_Init_thread(&argc, &argv, preferred, &provided);
+    PIKA_TEST_EQ(provided, preferred);
 
     // Start runtime and collect runtime exit status
-    auto result = pika::init(pika_main, argc, argv, init_args);
+    auto result = pika::init(pika_main, argc, argv);
     PIKA_TEST_EQ(result, 0);
 
     MPI_Finalize();
