@@ -13,6 +13,7 @@
 #include <pika/config.hpp>
 #include <pika/execution_base/this_thread.hpp>
 #include <pika/mpi_base/mpi_environment.hpp>
+#include <pika/runtime/runtime.hpp>
 #include <pika/threading_base/print.hpp>
 //
 #define RANK_OUTPUT (rank == 0)
@@ -44,7 +45,7 @@ constexpr int debug_level = 9;
 
 // cppcheck-suppress ConfigurationNotChecked
 template <int Level>
-static pika::debug::detail::print_threshold<Level, debug_level> nws_deb("STORAGE");
+inline constexpr pika::debug::detail::print_threshold<Level, debug_level> nws_deb("STORAGE");
 
 //----------------------------------------------------------------------------
 //
@@ -100,7 +101,7 @@ struct perf
 };
 
 //----------------------------------------------------------------------------
-void display(perf const& data, const test_options& options)
+void display(perf const& data, test_options const& options)
 {
     std::stringstream temp;
     double IOPs_s = data.IOPs / data.time;
@@ -143,12 +144,8 @@ void test_send_recv(std::uint32_t rank, std::uint32_t nranks, std::mt19937& gen,
     std::uniform_int_distribution<std::uint64_t>& random_offset,
     std::uniform_int_distribution<std::uint64_t>& random_slot, test_options& options)
 {
-    static deb::print_threshold<1, debug_level> write_arr(" WRITE ");
-
-    // this needs to scope all uses of mpi::experimental::executor
-    std::string poolname = "default";
-    if (pika::resource::pool_exists(mpi::get_pool_name())) { poolname = mpi::get_pool_name(); }
-    mpi::enable_user_polling enable_polling(poolname);
+    static constexpr deb::print_threshold<1, debug_level> write_arr(" WRITE ");
+    mpi::enable_polling enable_polling();
 
     pika::scoped_annotation annotate("test_write");
     std::stringstream temp;
@@ -234,12 +231,10 @@ void test_send_recv(std::uint32_t rank, std::uint32_t nranks, std::mt19937& gen,
             void* buffer_to_recv = &local_recv_storage[memory_offset_recv];
             auto rsnd = ex::just(buffer_to_recv, options.transfer_size_B, MPI_UNSIGNED_CHAR,
                             recv_rank, tag, MPI_COMM_WORLD) |
-                mpi::transform_mpi(MPI_Irecv, mpi::stream_type::receive_1) |
-                ex::then([&](int result) {
+                mpi::transform_mpi(MPI_Irecv) | ex::then([&]() {
                     --recvs_in_flight;
                     nws_deb<5>.debug(deb::str<>("recv complete"), "recv in flight", recvs_in_flight,
                         "send in flight", sends_in_flight);
-                    return result;
                 });
             ex::start_detached(std::move(rsnd));
 
@@ -257,11 +252,10 @@ void test_send_recv(std::uint32_t rank, std::uint32_t nranks, std::mt19937& gen,
             void* buffer_to_send = &local_send_storage[memory_offset_send];
             auto ssnd = ex::just(buffer_to_send, options.transfer_size_B, MPI_UNSIGNED_CHAR,
                             send_rank, tag, MPI_COMM_WORLD) |
-                mpi::transform_mpi(MPI_Isend, mpi::stream_type::send_1) | ex::then([&](int result) {
+                mpi::transform_mpi(MPI_Isend) | ex::then([&]() {
                     --sends_in_flight;
                     nws_deb<5>.debug(deb::str<>("send complete"), "recv in flight", recvs_in_flight,
                         "send in flight", sends_in_flight);
-                    return result;
                 });
             launch_on_default_pool(std::move(ssnd));
         }
@@ -342,12 +336,15 @@ void test_send_recv(std::uint32_t rank, std::uint32_t nranks, std::mt19937& gen,
 int pika_main(pika::program_options::variables_map& vm)
 {
     // Disable idle backoff on the default pool
-    pika::threads::remove_scheduler_mode(::pika::threads::scheduler_mode::enable_idle_backoff);
+    pika::detail::remove_scheduler_mode(pika::threads::scheduler_mode::enable_idle_backoff);
 
-    pika::util::mpi_environment mpi_env;
+    pika::mpi::detail::environment mpi_env;
     pika::detail::runtime* rt = pika::detail::get_runtime_ptr();
     pika::util::runtime_configuration cfg = rt->get_config();
-    mpi_env.init(nullptr, nullptr, cfg);
+    int minimal = MPI_THREAD_MULTIPLE;
+    int required = MPI_THREAD_MULTIPLE;
+    int provided = 0;
+    mpi_env.init(nullptr, nullptr, required, minimal, provided);
 
     pika::chrono::detail::high_resolution_timer timer_main;
     nws_deb<2>.debug(deb::str<>("PIKA main"));
@@ -450,30 +447,6 @@ int pika_main(pika::program_options::variables_map& vm)
     return EXIT_SUCCESS;
 }
 
-//----------------------------------------------------------------------------
-void init_resource_partitioner_handler(
-    pika::resource::partitioner& rp, pika::program_options::variables_map const& vm)
-{
-    // Don't create the MPI pool if the user disabled it
-    if (vm["no-mpi-pool"].as<bool>()) return;
-
-    // Don't create the MPI pool if there is a single process
-    int ntasks;
-    MPI_Comm_size(MPI_COMM_WORLD, &ntasks);
-    if (ntasks == 1) return;
-
-    // Disable idle backoff on the MPI pool
-    using pika::threads::scheduler_mode;
-    auto mode = scheduler_mode::default_mode;
-    mode = scheduler_mode(mode & ~scheduler_mode::enable_idle_backoff);
-
-    // Create a thread pool with a single core that we will use for all
-    // communication related tasks
-    rp.create_thread_pool(
-        mpi::get_pool_name(), pika::resource::scheduling_policy::local_priority_fifo, mode);
-    rp.add_resource(rp.sockets()[0].cores()[0].pus()[0], mpi::get_pool_name());
-}
-
 //----------------------------------------------------------------------------
 int main(int argc, char* argv[])
 {
@@ -490,9 +463,6 @@ int main(int argc, char* argv[])
     pika::program_options::options_description cmdline(
         "Usage: " PIKA_APPLICATION_STRING " [options]");
 
-    cmdline.add_options()(
-        "no-mpi-pool", pika::program_options::bool_switch(), "Disable the MPI pool.");
-
     cmdline.add_options()("in-flight-limit",
         pika::program_options::value<std::uint32_t>()->default_value(
             mpi::get_max_requests_in_flight()),
@@ -514,9 +484,6 @@ int main(int argc, char* argv[])
     nws_deb<6>.debug(3, "Calling pika::init");
     pika::init_params init_args;
     init_args.desc_cmdline = cmdline;
-    // Set the callback to init thread_pools
-    init_args.rp_callback = &init_resource_partitioner_handler;
-
     auto result = pika::init(pika_main, argc, argv, init_args);
     PIKA_TEST_EQ(result, 0);
 
