@@ -26,14 +26,14 @@ struct MaybeThrowOnCopy
     {
     }
 
-    MaybeThrowOnCopy(const MaybeThrowOnCopy& other)
+    MaybeThrowOnCopy(MaybeThrowOnCopy const& other)
       : value(other.value)
     {
         if (throwOnCopy) throw tried_to_copy();
     }
 
     // NOLINTNEXTLINE(bugprone-unhandled-self-assignment)
-    MaybeThrowOnCopy& operator=(const MaybeThrowOnCopy& other)
+    MaybeThrowOnCopy& operator=(MaybeThrowOnCopy const& other)
     {
         if (throwOnCopy) throw tried_to_copy();
         value = other.value;
