@@ -25,13 +25,13 @@ namespace pika::program_options {
     // First, performs semantic actions for 'oa'.
     // Then, stores in 'm' all options that are defined in 'desc'.
     PIKA_EXPORT
-    void store(const parsed_options& options, variables_map& xm, bool utf8)
+    void store(parsed_options const& options, variables_map& xm, bool utf8)
     {
         // TODO: what if we have different definition
         // for the same option name during different calls
         // 'store'.
         PIKA_ASSERT(options.description);
-        const options_description& desc = *options.description;
+        options_description const& desc = *options.description;
 
         // We need to access map's operator[], not the overridden version
         // variables_map. Ehmm.. messy.
@@ -67,7 +67,7 @@ namespace pika::program_options {
                 if (xm.m_final.count(option_name)) continue;
 
                 original_token = !opts.original_tokens.empty() ? opts.original_tokens[0] : "";
-                const option_description& d = desc.find(option_name, false, false, false);
+                option_description const& d = desc.find(option_name, false, false, false);
 
                 variable_value& v = m[option_name];
                 if (v.defaulted())
@@ -98,10 +98,10 @@ namespace pika::program_options {
         xm.m_final.insert(new_final.begin(), new_final.end());
 
         // Second, apply default values and store required options.
-        const vector<shared_ptr<option_description>>& all = desc.options();
+        vector<shared_ptr<option_description>> const& all = desc.options();
         for (i = 0; i < all.size(); ++i)
         {
-            const option_description& d = *all[i];
+            option_description const& d = *all[i];
             string key = d.key("");
             // FIXME: this logic relies on knowledge of option_description
             // internals.
@@ -133,7 +133,7 @@ namespace pika::program_options {
         }
     }
 
-    void store(const wparsed_options& options, variables_map& m)
+    void store(wparsed_options const& options, variables_map& m)
     {
         store(options.utf8_encoded_options, m, true);
     }
@@ -145,19 +145,19 @@ namespace pika::program_options {
     {
     }
 
-    abstract_variables_map::abstract_variables_map(const abstract_variables_map* next)
+    abstract_variables_map::abstract_variables_map(abstract_variables_map const* next)
       : m_next(next)
     {
     }
 
-    const variable_value& abstract_variables_map::operator[](const std::string& name) const
+    variable_value const& abstract_variables_map::operator[](std::string const& name) const
     {
-        const variable_value& v = get(name);
+        variable_value const& v = get(name);
         if (v.empty() && m_next)
             return (*m_next)[name];
         else if (v.defaulted() && m_next)
         {
-            const variable_value& v2 = (*m_next)[name];
+            variable_value const& v2 = (*m_next)[name];
             if (!v2.empty() && !v2.defaulted())
                 return v2;
             else
@@ -170,7 +170,7 @@ namespace pika::program_options {
 
     variables_map::variables_map() {}
 
-    variables_map::variables_map(const abstract_variables_map* next)
+    variables_map::variables_map(abstract_variables_map const* next)
       : abstract_variables_map(next)
     {
     }
@@ -182,7 +182,7 @@ namespace pika::program_options {
         m_required.clear();
     }
 
-    const variable_value& variables_map::get(const std::string& name) const
+    variable_value const& variables_map::get(std::string const& name) const
     {
         static variable_value empty;
         const_iterator i = this->find(name);
@@ -197,8 +197,8 @@ namespace pika::program_options {
         // This checks if all required options occur
         for (map<string, string>::const_iterator r = m_required.begin(); r != m_required.end(); ++r)
         {
-            const string& opt = r->first;
-            const string& display_opt = r->second;
+            string const& opt = r->first;
+            string const& display_opt = r->second;
             map<string, variable_value>::const_iterator iter = find(opt);
             if (iter == end() || iter->second.empty()) { throw required_option(display_opt); }
         }
