@@ -650,7 +650,7 @@ namespace pika::resource::detail {
     void partitioner::add_resource(
         std::vector<core> const& cv, std::string const& pool_name, bool exclusive)
     {
-        for (const core& c : cv) { add_resource(c.pus_, pool_name, exclusive); }
+        for (core const& c : cv) { add_resource(c.pus_, pool_name, exclusive); }
     }
 
     void partitioner::add_resource(socket const& nd, std::string const& pool_name, bool exclusive)
@@ -661,7 +661,7 @@ namespace pika::resource::detail {
     void partitioner::add_resource(
         std::vector<socket> const& ndv, std::string const& pool_name, bool exclusive)
     {
-        for (const socket& d : ndv) { add_resource(d, pool_name, exclusive); }
+        for (socket const& d : ndv) { add_resource(d, pool_name, exclusive); }
     }
 
     void partitioner::set_scheduler(scheduling_policy sched, std::string const& pool_name)
@@ -732,7 +732,7 @@ namespace pika::resource::detail {
         return get_pool_data(l, pool_index).num_threads_;
     }
 
-    std::size_t partitioner::get_num_threads(const std::string& pool_name) const
+    std::size_t partitioner::get_num_threads(std::string const& pool_name) const
     {
         std::unique_lock<mutex_type> l(mtx_);
         return get_pool_data(l, pool_name).num_threads_;
