@@ -23,10 +23,8 @@ int pika_main()
 
 int main(int argc, char** argv)
 {
-    std::vector<std::string> cfg = {"--pika:help"};
-
     pika::init_params init_args;
-    init_args.cfg = cfg;
+    init_args.cfg = {"--pika:help"};
 
     PIKA_TEST_EQ(pika::init(pika_main, argc, argv, init_args), 0);
 
