@@ -13,6 +13,7 @@
 #include <pika/thread.hpp>
 
 #include <cstddef>
+#include <cstdlib>
 #include <string>
 #include <utility>
 #include <vector>
@@ -42,7 +43,8 @@ int pika_main()
         PIKA_TEST_EQ(std::size_t(0), pool.get_thread_offset());
     }
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char* argv[])
