@@ -9,7 +9,7 @@
 #include <typeinfo>
 
 namespace pika::detail {
-    const char* bad_lexical_cast::what() const noexcept
+    char const* bad_lexical_cast::what() const noexcept
     {
         return "bad lexical cast: source type value could not be interpreted as target";
     }
