@@ -10,8 +10,8 @@
 #include <pika/coroutines/detail/coroutine_accessor.hpp>
 #include <pika/functional/function.hpp>
 #include <pika/lock_registration/detail/register_locks.hpp>
+#include <pika/logging.hpp>
 #include <pika/modules/errors.hpp>
-#include <pika/modules/logging.hpp>
 #include <pika/thread_support/unlock_guard.hpp>
 #include <pika/threading_base/scheduler_base.hpp>
 #include <pika/threading_base/thread_data.hpp>
@@ -57,8 +57,7 @@ namespace pika::threads::detail {
       , stacksize_enum_(init_data.stacksize)
       , queue_(queue)
     {
-        LTM_(debug).format(
-            "thread::thread({}), description({})", fmt::ptr(this), get_description());
+        PIKA_LOG(debug, "thread::thread({}), description({})", fmt::ptr(this), get_description());
 
         PIKA_ASSERT(stacksize_enum_ != execution::thread_stacksize::current);
 
@@ -82,13 +81,13 @@ namespace pika::threads::detail {
 
     thread_data::~thread_data()
     {
-        LTM_(debug).format("thread_data::~thread_data({})", fmt::ptr(this));
+        PIKA_LOG(debug, "thread_data::~thread_data({})", fmt::ptr(this));
         free_thread_exit_callbacks();
     }
 
     void thread_data::destroy_thread()
     {
-        LTM_(debug).format("thread_data::destroy_thread({}), description({}), phase({})",
+        PIKA_LOG(debug, "thread_data::destroy_thread({}), description({}), phase({})",
             fmt::ptr(this), this->get_description(), this->get_thread_phase());
 
         get_scheduler_base()->destroy_thread(this);
@@ -161,7 +160,7 @@ namespace pika::threads::detail {
 
     void thread_data::rebind_base(thread_init_data& init_data)
     {
-        LTM_(debug).format("thread_data::rebind_base({}), description({}), phase({}), rebind",
+        PIKA_LOG(debug, "thread_data::rebind_base({}), description({}), phase({}), rebind",
             fmt::ptr(this), get_description(), get_thread_phase());
 
         free_thread_exit_callbacks();
@@ -197,8 +196,8 @@ namespace pika::threads::detail {
         PIKA_ASSERT(stacksize_ == get_stack_size());
         PIKA_ASSERT(stacksize_ != 0);
 
-        LTM_(debug).format(
-            "thread::thread({}), description({}), rebind", fmt::ptr(this), get_description());
+        PIKA_LOG(debug, "thread::thread({}), description({}), rebind", fmt::ptr(this),
+            get_description());
 
 #ifdef PIKA_HAVE_THREAD_PARENT_REFERENCE
         // store the thread id of the parent thread, mainly for debugging
