@@ -12,6 +12,6 @@ for file in $(git ls-files | grep -E "\.(cpp|hpp|cu)(\.in)?$"); do
     # to allow for per-directory clang format files, we cd into the dir first
     DIR=$(dirname "$file")
     pushd ${DIR} >/dev/null
-    clang-format -i $(basename -- ${file})
+    clang-format-16 -i $(basename -- ${file})
     popd >/dev/null
 done
